==> bitso-ts-0.3.0.tgz: package/src/bitso/private/Account.ts <==
import { AxiosRequestConfig, AxiosResponse } from 'axios';
import HttpClient from '../../services/HttpClient';
import SigningRequest from '../helpers/SigningRequest';
import { Account, AccountBalance } from '../types/Account';
import { host } from '../types/client';
import { Fees } from '../types/Fees';

export class AccountAPI extends HttpClient {
  private _signReq: SigningRequest;

  constructor(
    { version, test }: { version: string; test?: boolean },
    signRequest: SigningRequest
  ) {
    super(test ? host.TEST : host.PROD + '/' + version + '/');
    this._initializeResponseInterceptor();
    this._initializeRequestInterceptor();
    this._signReq = signRequest;
  }

  public async getAccountBalance(): Promise<[AccountBalance]> {
    const endpoint = 'balance';
    this.setRequest({
      method: 'GET',
      payload: {},
      endpoint: endpoint,
    });
    return await this._httpClient.get<[AccountBalance]>(endpoint);
  }

  public async getAccountStatus(): Promise<Account> {
    const endpoint = 'account_status';
    this.setRequest({
      method: 'GET',
      payload: {},
      endpoint: endpoint
    });
    return await this._httpClient.get<Account>(endpoint);
  }

  public async getFees(): Promise<Fees> {
    const endpoint = 'fees';
    this.setRequest({
      method: 'GET',
      payload: {},
      endpoint: endpoint
    });
    return await this._httpClient.get<Fees>(endpoint);
  }

  private setRequest({
    method,
    payload,
    endpoint,
  }: {
    method: string;
    payload?: any;
    endpoint: string;
  }): void {
    this._signReq.method(method);
    this._signReq.payload(payload);
    this._signReq.endpoint(endpoint);
  }
  private _initializeResponseInterceptor(): void {
    this._httpClient.interceptors.response.use(
      this._handleResponse,
      this._handleError
    );
  }

  private _initializeRequestInterceptor = () => {
    this._httpClient.interceptors.request.use(
      this._handleRequest,
      this._handleError
    );
  };

  private _handleRequest = (config: AxiosRequestConfig) => {
    config.headers['Authorization'] = this._signReq.getHeader();
    return config;
  };

  private _handleResponse = ({ data }: AxiosResponse) => data.payload;

  protected _handleError = (error: any) => Promise.reject(error);
}

==> bitso-ts-0.3.8.tgz: package/src/bitso/private/Account.ts <==
import { AxiosRequestConfig, AxiosResponse } from 'axios';
import HttpClient from '../../services/HttpClient';
import SigningRequest from '../helpers/SigningRequest';
import { Account, AccountBalance } from '../types/Account';
import { host } from '../types/client';
import { Fees } from '../types/Fees';

export class AccountAPI extends HttpClient {
  private _signReq: SigningRequest;

  constructor(
    { version, test }: { version: string; test?: boolean },
    signRequest: SigningRequest
  ) {
    super(test ? host.TEST : host.PROD + '/' + version + '/');
    this._initializeResponseInterceptor();
    this._initializeRequestInterceptor();
    this._signReq = signRequest;
  }

  public async getAccountBalance(): Promise<[AccountBalance]> {
    const endpoint = 'balance';


    this._signReq.method = 'GET';
    this._signReq.payload  = {};
    this._signReq.endpoint = endpoint;

    return await this._httpClient.get<[AccountBalance]>(endpoint);
  }

  public async getAccountStatus(): Promise<Account> {
    const endpoint = 'account_status';


    this._signReq.method = 'GET';
    this._signReq.payload  = {};
    this._signReq.endpoint = endpoint;


    return await this._httpClient.get<Account>(endpoint);
  }

  public async getFees(): Promise<Fees> {
    const endpoint = 'fees';

    this._signReq.method = 'GET';
    this._signReq.payload  = {};
    this._signReq.endpoint = endpoint;

    return await this._httpClient.get<Fees>(endpoint);
  }

  private _initializeResponseInterceptor(): void {
    this._httpClient.interceptors.response.use(
      this._handleResponse,
      this._handleError
    );
  }

  private _initializeRequestInterceptor = () => {
    this._httpClient.interceptors.request.use(
      this._handleRequest,
      this._handleError
    );
  };

  private _handleRequest = (config: AxiosRequestConfig) => {
    config.headers['Authorization'] = this._signReq.getHeader();
    return config;
  };

  private _handleResponse = ({ data }: AxiosResponse) => data.payload;

  protected _handleError = (error: any) => Promise.reject(error);
}
